# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['flair',
 'flair.datasets',
 'flair.embeddings',
 'flair.hyperparameter',
 'flair.models',
 'flair.trainers',
 'flair.visual']

package_data = \
{'': ['*']}

install_requires = \
['deprecated', 'numpy', 'requests', 'torch', 'tqdm']

setup_kwargs = {
    'name': 'pd3f-flair',
    'version': '0.6.0.1',
    'description': "Flair's language models without unnecessary dependencies",
    'long_description': '# NB: This is a Fork\n\nFlair\'s Language Models without unnecessary dependencies.\n\nThis package removed all the unnecessary dependencies if you only want to use Flair\'s character-based language models.\nFlair listed all kind of optional requirements as hard requirments.\nThis made the installation tedious and bloated.\n\n```bash\npip install pd3f-flair\n```\n\n\n\n![alt text](resources/docs/flair_logo_2020.png)\n\n[![PyPI version](https://badge.fury.io/py/flair.svg)](https://badge.fury.io/py/flair)\n[![GitHub Issues](https://img.shields.io/github/issues/flairNLP/flair.svg)](https://github.com/flairNLP/flair/issues)\n[![Contributions welcome](https://img.shields.io/badge/contributions-welcome-brightgreen.svg)](CONTRIBUTING.md)\n[![License: MIT](https://img.shields.io/badge/License-MIT-brightgreen.svg)](https://opensource.org/licenses/MIT)\n[![Travis](https://img.shields.io/travis/flairNLP/flair.svg)](https://travis-ci.org/flairNLP/flair)\n\nA very simple framework for **state-of-the-art NLP**. Developed by [Humboldt University of Berlin](https://www.informatik.hu-berlin.de/en/forschung-en/gebiete/ml-en/) and friends.\n\n* __IMPORTANT: (30.08.2020)__ *We moved our models to a new server. Please update your Flair to the newest version!*\n\n---\n\nFlair is:\n\n* **A powerful NLP library.** Flair allows you to apply our state-of-the-art natural language processing (NLP)\nmodels to your text, such as named entity recognition (NER), part-of-speech tagging (PoS),\n sense disambiguation and classification, with support for a rapidly growing number of languages.\n\n* **A biomedical NER library.** Flair has special support for [biomedical data](/resources/docs/HUNFLAIR.md) with\nstate-of-the-art models for biomedical NER and support for over 32 biomedical datasets.\n\n* **A text embedding library.** Flair has simple interfaces that allow you to use and combine different word and\ndocument embeddings, including our proposed **[Flair embeddings](https://www.aclweb.org/anthology/C18-1139/)**, BERT embeddings and ELMo embeddings.\n\n* **A PyTorch NLP framework.** Our framework builds directly on [PyTorch](https://pytorch.org/), making it easy to\ntrain your own models and experiment with new approaches using Flair embeddings and classes.\n\nNow at [version 0.6](https://github.com/flairNLP/flair/releases)!\n\n## Comparison with State-of-the-Art\n\nFlair outperforms the previous best methods on a range of NLP tasks:\n\n| Task                      | Language | Dataset      | Flair                                                                                    | Previous best                                                                                                 |\n| ------------------------- | -------- | ------------ | ---------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------- |\n| Named Entity Recognition  | English  | Conll-03     | **93.18** (F1)                                                                           | *92.22 [(Peters et al., 2018)](https://arxiv.org/pdf/1802.05365.pdf)*                                         |\n| Named Entity Recognition  | English  | Ontonotes    | **89.3** (F1)                                                                            | *86.28 [(Chiu et al., 2016)](https://arxiv.org/pdf/1511.08308.pdf)*                                           |\n| Emerging Entity Detection | English  | WNUT-17      | **49.49** (F1)                                                                           | *45.55 [(Aguilar et al., 2018)](http://aclweb.org/anthology/N18-1127.pdf)*                                    |\n| Part-of-Speech tagging    | English  | WSJ          | **97.85**                                                                                | *97.64 [(Choi, 2016)](https://www.aclweb.org/anthology/N16-1031)*                                             |\n| Chunking                  | English  | Conll-2000   | **96.72** (F1)                                                                           | *96.36 [(Peters et al., 2017)](https://arxiv.org/pdf/1705.00108.pdf)*                                         |\n| Named Entity Recognition  | German   | Conll-03     | **88.27** (F1)                                                                           | *78.76 [(Lample et al., 2016)](https://arxiv.org/abs/1603.01360)*                                             |\n| Named Entity Recognition  | German   | Germeval     | **84.65** (F1)                                                                           | *79.08 [(Hänig et al, 2014)](http://asv.informatik.uni-leipzig.de/publication/file/300/GermEval2014_ExB.pdf)* |\n| Named Entity Recognition  | Dutch    | Conll-02     | **92.38** (F1)                                                                           | *81.74 [(Lample et al., 2016)](https://arxiv.org/abs/1603.01360)*                                             |\n| Named Entity Recognition  | Polish   | PolEval-2018 | **86.6** (F1) <br> [(Borchmann et al., 2018)](https://github.com/applicaai/poleval-2018) | *85.1 [(PolDeepNer)](https://github.com/CLARIN-PL/PolDeepNer/)*                                               |\n\nHere\'s how to [reproduce these numbers](/resources/docs/EXPERIMENTS.md) using Flair. You can also find detailed evaluations and discussions in our papers:\n\n* *[Contextual String Embeddings for Sequence Labeling](https://www.aclweb.org/anthology/C18-1139/).\nAlan Akbik, Duncan Blythe and Roland Vollgraf.\n27th International Conference on Computational Linguistics, **COLING 2018**.*\n\n* *[Pooled Contextualized Embeddings for Named Entity Recognition](https://www.aclweb.org/anthology/papers/N/N19/N19-1078/).\nAlan Akbik, Tanja Bergmann and Roland Vollgraf.\n2019 Annual Conference of the North American Chapter of the Association for Computational Linguistics, **NAACL 2019**.*\n\n* *[FLAIR: An Easy-to-Use Framework for State-of-the-Art NLP](https://www.aclweb.org/anthology/papers/N/N19/N19-4010/).\nAlan Akbik, Tanja Bergmann, Duncan Blythe, Kashif Rasul, Stefan Schweter and Roland Vollgraf.\n2019 Annual Conference of the North American Chapter of the Association for Computational Linguistics (Demonstrations), **NAACL 2019**.*\n\n## Quick Start\n\n### Requirements and Installation\n\nThe project is based on PyTorch 1.1+ and Python 3.6+, because method signatures and type hints are beautiful.\nIf you do not have Python 3.6, install it first. [Here is how for Ubuntu 16.04](https://vsupalov.com/developing-with-python3-6-on-ubuntu-16-04/).\nThen, in your favorite virtual environment, simply do:\n\n```\npip install flair\n```\n\n### Example Usage\n\nLet\'s run named entity recognition (NER) over an example sentence. All you need to do is make a `Sentence`, load\na pre-trained model and use it to predict tags for the sentence:\n\n```python\nfrom flair.data import Sentence\nfrom flair.models import SequenceTagger\n\n# make a sentence\nsentence = Sentence(\'I love Berlin .\')\n\n# load the NER tagger\ntagger = SequenceTagger.load(\'ner\')\n\n# run NER over sentence\ntagger.predict(sentence)\n```\n\nDone! The `Sentence` now has entity annotations. Print the sentence to see what the tagger found.\n\n```python\nprint(sentence)\nprint(\'The following NER tags are found:\')\n\n# iterate over entities and print\nfor entity in sentence.get_spans(\'ner\'):\n    print(entity)\n```\n\nThis should print:\n\n```console\nSentence: "I love Berlin ." - 4 Tokens\n\nThe following NER tags are found:\n\nSpan [3]: "Berlin"   [− Labels: LOC (0.9992)]\n```\n\n## Tutorials\n\nWe provide a set of quick tutorials to get you started with the library:\n\n* [Tutorial 1: Basics](/resources/docs/TUTORIAL_1_BASICS.md)\n* [Tutorial 2: Tagging your Text](/resources/docs/TUTORIAL_2_TAGGING.md)\n* [Tutorial 3: Embedding Words](/resources/docs/TUTORIAL_3_WORD_EMBEDDING.md)\n* [Tutorial 4: List of All Word Embeddings](/resources/docs/TUTORIAL_4_ELMO_BERT_FLAIR_EMBEDDING.md)\n* [Tutorial 5: Embedding Documents](/resources/docs/TUTORIAL_5_DOCUMENT_EMBEDDINGS.md)\n* [Tutorial 6: Loading a Dataset](/resources/docs/TUTORIAL_6_CORPUS.md)\n* [Tutorial 7: Training a Model](/resources/docs/TUTORIAL_7_TRAINING_A_MODEL.md)\n* [Tutorial 8: Training your own Flair Embeddings](/resources/docs/TUTORIAL_9_TRAINING_LM_EMBEDDINGS.md)\n\nThe tutorials explain how the base NLP classes work, how you can load pre-trained models to tag your\ntext, how you can embed your text with different word or document embeddings, and how you can train your own\nlanguage models, sequence labeling models, and text classification models. Let us know if anything is unclear.\n\nThere is also a dedicated landing page for our **[biomedical NER and datasets](/resources/docs/HUNFLAIR.md)** with\ninstallation instructions and tutorials.\n\nThere are also good third-party articles and posts that illustrate how to use Flair:\n* [How to build a text classifier with Flair](https://towardsdatascience.com/text-classification-with-state-of-the-art-nlp-library-flair-b541d7add21f)\n* [How to build a microservice with Flair and Flask](https://shekhargulati.com/2019/01/04/building-a-sentiment-analysis-python-microservice-with-flair-and-flask/)\n* [A docker image for Flair](https://towardsdatascience.com/docker-image-for-nlp-5402c9a9069e)\n* [Great overview of Flair functionality and how to use in Colab](https://www.analyticsvidhya.com/blog/2019/02/flair-nlp-library-python/)\n* [Visualisation tool for highlighting the extracted entities](https://github.com/lunayach/visNER)\n* [Practical approach of State-of-the-Art Flair in Named Entity Recognition](https://medium.com/analytics-vidhya/practical-approach-of-state-of-the-art-flair-in-named-entity-recognition-46a837e25e6b)\n* [Benchmarking NER algorithms](https://towardsdatascience.com/benchmark-ner-algorithm-d4ab01b2d4c3)\n* [Training a Flair text classifier on Google Cloud Platform (GCP) and serving predictions on GCP](https://github.com/robinvanschaik/flair-on-gcp)\n\n## Citing Flair\n\nPlease cite the following paper when using Flair:\n\n```\n@inproceedings{akbik2018coling,\n  title={Contextual String Embeddings for Sequence Labeling},\n  author={Akbik, Alan and Blythe, Duncan and Vollgraf, Roland},\n  booktitle = {{COLING} 2018, 27th International Conference on Computational Linguistics},\n  pages     = {1638--1649},\n  year      = {2018}\n}\n```\n\nIf you use the pooled version of the Flair embeddings (PooledFlairEmbeddings), please cite:\n\n```\n@inproceedings{akbik2019naacl,\n  title={Pooled Contextualized Embeddings for Named Entity Recognition},\n  author={Akbik, Alan and Bergmann, Tanja and Vollgraf, Roland},\n  booktitle = {{NAACL} 2019, 2019 Annual Conference of the North American Chapter of the Association for Computational Linguistics},\n  pages     = {724–728},\n  year      = {2019}\n}\n```\n\n## Contact\n\nPlease email your questions or comments to [Alan Akbik](http://alanakbik.github.io/).\n\n## Contributing\n\nThanks for your interest in contributing! There are many ways to get involved;\nstart with our [contributor guidelines](CONTRIBUTING.md) and then\ncheck these [open issues](https://github.com/flairNLP/flair/issues) for specific tasks.\n\nFor contributors looking to get deeper into the API we suggest cloning the repository and checking out the unit\ntests for examples of how to call methods. Nearly all classes and methods are documented, so finding your way around\nthe code should hopefully be easy.\n\n### Running unit tests locally\n\nYou need [Pipenv](https://pipenv.readthedocs.io/) for this:\n\n```bash\npipenv install --dev && pipenv shell\npytest tests/\n```\n\nTo run integration tests execute:\n```bash\npytest --runintegration tests/\n```\nThe integration tests will train small models.\nAfterwards, the trained model will be loaded for prediction.\n\nTo also run slow tests, such as loading and using the embeddings provided by flair, you should execute:\n```bash\npytest --runslow tests/\n```\n\n## [License](/LICENSE)\n\nThe MIT License (MIT)\n\nFlair is licensed under the following MIT license: The MIT License (MIT) Copyright © 2018 Zalando SE, https://tech.zalando.com\n\nPermission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the “Software”), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.\n',
    'author': 'Alan Akbik',
    'author_email': 'alan.akbik@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6',
}


setup(**setup_kwargs)
